@@ -1,5 +1,7 @@
 var NAVTREEINDEX125 =
 {
+"dd/dc5/translator__class_8h_source.html":[8,0,0,2,25,16],
+"dd/dc6/lease__update__backlog_8h.html":[8,0,0,1,0,2,21],
 "dd/dc6/lease__update__backlog_8h_source.html":[8,0,0,1,0,2,21],
 "dd/dca/output__option_8h.html":[8,0,0,2,18,41],
 "dd/dca/output__option_8h.html#a21b969d8e9cbf1574aa918052b03cfa9":[8,0,0,2,18,41,1],
@@ -247,7 +249,5 @@ var NAVTREEINDEX125 =
 "dd/dfa/hooksComponentDeveloperGuide.html#hooksComponentLoadLibraries":[0,15,5],
 "dd/dfa/hooksComponentDeveloperGuide.html#hooksComponentNextStep":[0,15,4,2],
 "dd/dfa/hooksComponentDeveloperGuide.html#hooksComponentRegistration":[0,15,3],
-"dd/dfa/hooksComponentDeveloperGuide.html#hooksComponentSkipFlag":[0,15,4,1],
-"dd/dfa/hooksComponentDeveloperGuide.html#hooksComponentTerminology":[0,15,0,0],
-"dd/dfa/hooksComponentDeveloperGuide.html#hooksComponentUnloadIssues":[0,15,5,0]
+"dd/dfa/hooksComponentDeveloperGuide.html#hooksComponentSkipFlag":[0,15,4,1]
 };
