@@ -1,5 +1,7 @@
 var NAVTREEINDEX133 =
 {
+"de/dd3/classisc_1_1dhcp_1_1OptionCustom.html#a80ba54e3a388bf20d0ac2e52153a6a0f":[7,0,1,9,194,2],
+"de/dd3/classisc_1_1dhcp_1_1OptionCustom.html#a80ba54e3a388bf20d0ac2e52153a6a0f":[6,0,2,11,194,2],
 "de/dd3/classisc_1_1dhcp_1_1OptionCustom.html#a85f0677c41e706c40577df14daf25c75":[6,0,2,11,194,19],
 "de/dd3/classisc_1_1dhcp_1_1OptionCustom.html#a85f0677c41e706c40577df14daf25c75":[7,0,1,9,194,19],
 "de/dd3/classisc_1_1dhcp_1_1OptionCustom.html#a977428e6d3df1f61a1c449e0d64e243e":[7,0,1,9,194,28],
@@ -247,7 +249,5 @@ var NAVTREEINDEX133 =
 "de/df3/dhcpv4Hooks.html#dhcpv4HooksIntroduction":[0,11,0],
 "de/df3/dhcpv4Hooks.html#dhcpv4HooksLease4Expire":[0,11,1,13],
 "de/df3/dhcpv4Hooks.html#dhcpv4HooksLease4Recover":[0,11,1,14],
-"de/df3/dhcpv4Hooks.html#dhcpv4HooksLeaseDecline":[0,11,1,9],
-"de/df3/dhcpv4Hooks.html#dhcpv4HooksLeaseRelease":[0,11,1,8],
-"de/df3/dhcpv4Hooks.html#dhcpv4HooksLeaseRenew":[0,11,1,7]
+"de/df3/dhcpv4Hooks.html#dhcpv4HooksLeaseDecline":[0,11,1,9]
 };
