@@ -1,5 +1,7 @@
 var NAVTREEINDEX134 =
 {
+"de/df3/dhcpv4Hooks.html#dhcpv4HooksLeaseRelease":[0,11,1,8],
+"de/df3/dhcpv4Hooks.html#dhcpv4HooksLeaseRenew":[0,11,1,7],
 "de/df3/dhcpv4Hooks.html#dhcpv4HooksLeaseSelect":[0,11,1,6],
 "de/df3/dhcpv4Hooks.html#dhcpv4HooksOptionsAccess":[0,11,2],
 "de/df3/dhcpv4Hooks.html#dhcpv4HooksPkt4Receive":[0,11,1,3],
@@ -247,7 +249,5 @@ var NAVTREEINDEX134 =
 "df/d0c/classisc_1_1dhcp_1_1TokenHexString.html#a6c4f62bafe7344547ecf87d3619d750c":[6,0,2,11,324,2],
 "df/d0c/classisc_1_1dhcp_1_1TokenHexString.html#accf540649d1e95af4a3cd7584dd5682a":[6,0,2,11,324,0],
 "df/d0c/classisc_1_1dhcp_1_1TokenHexString.html#accf540649d1e95af4a3cd7584dd5682a":[7,0,1,9,324,0],
-"df/d0c/classisc_1_1dhcp_1_1TokenSubstring.html":[7,0,1,9,344],
-"df/d0c/classisc_1_1dhcp_1_1TokenSubstring.html":[6,0,2,11,344],
-"df/d0c/classisc_1_1dhcp_1_1TokenSubstring.html#ab2b544b09c4c202957957a583d72ea4a":[7,0,1,9,344,1]
+"df/d0c/classisc_1_1dhcp_1_1TokenSubstring.html":[7,0,1,9,344]
 };
